@@ -2,8 +2,7 @@ from django.db import models
 from shortuuidfield import ShortUUIDField
 from django.db.models import CharField
 from django.utils.translation import gettext_lazy as _
-from bartab_core.utils.validate import is_valid_short_uuid
-from django.core.exceptions import ValidationError
+from bartab_core.utils.validate import is_valid_short_uuid, is_valid_uuid
 from django.db import IntegrityError
 
 
@@ -23,22 +22,56 @@ class AbstractBaseModel(models.Model):
         return f'<{self.__class__.__name__} {self.uuid}>'
 
 
+class UserField(CharField):
+    description = 'User field'
+
+    def __init__(self, *args, **kwargs):
+        kwargs['max_length'] = 36
+
+        if 'null' not in kwargs:
+            kwargs['null'] = False
+
+        if 'blank' not in kwargs:
+            kwargs['blank'] = False
+
+        super().__init__(*args, **kwargs)
+
+    def pre_save(self, model_instance, add: bool):
+        value = super().pre_save(model_instance, add)
+
+        if self.null and value == None:
+            return value
+        elif self.blank and value == '':
+            return value
+        elif not is_valid_uuid(value):
+            raise IntegrityError("Invalid uuid")
+        else:
+            return value
+
 class MicroserviceForginKey(CharField):
     description = _("Key used by different BarTab microservice")
 
 
     def __init__(self, *args, **kwargs):
+        print(kwargs)
         kwargs['max_length'] = 22
 
-        kwargs['blank'] = False
-        kwargs['null'] = False
+        if 'null' not in kwargs:
+            kwargs['null'] = False
+
+        if 'blank' not in kwargs:
+            kwargs['blank'] = False
 
         super().__init__(*args, **kwargs)
 
-    def pre_save(self, model_instance,   add: bool):
+    def pre_save(self, model_instance, add: bool):
         value = super().pre_save(model_instance, add)
 
-        if not is_valid_short_uuid(value):
+        if self.null and value == None:
+            return value
+        elif self.blank and value == '':
+            return value
+        elif not is_valid_short_uuid(value):
             raise IntegrityError("Invalid short uuid")
-        
-        return value
+        else:
+            return value
